<?php
declare(strict_types=1);

namespace Inti\Media\Filesystem\Adapter;

use Interop\Container\ContainerInterface;
use Inti\Image\Convert\GdConvert;
use Inti\Image\Optimize\DefaultOptimize;
use Inti\Image\Resize\ImagickResize;
use Laminas\ServiceManager\AbstractPluginManager;
use Laminas\ServiceManager\Factory\FactoryInterface;
use League\Flysystem\FilesystemAdapter;

/**
 * Class ImageFilesystemAdapterFactory
 *
 * @package Inti\Media\Filesystem\Adapter
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-media
 */
final class ImageFilesystemAdapterFactory implements FactoryInterface
{
    /**
     * @param ContainerInterface $container
     * @param string $requestedName
     * @param array|null $options
     * @return FilesystemAdapter
     * @noinspection PhpMissingParamTypeInspection
     */
    public function __invoke(ContainerInterface $container, $requestedName, array $options = null): FilesystemAdapter
    {
        /** @var AbstractPluginManager $filesystemAdapters */
        $filesystemAdapters = $container->get('FilesystemAdapters');
        $adapter = $filesystemAdapters->get('local', $options);

        return new ImageFilesystemAdapter($adapter, new GdConvert(), new DefaultOptimize(), new ImagickResize());
    }
}
